@@ -1,11 +1,14 @@
 from dataservice.clients import (
-    PLAYWRIGHT_AVAILABLE,
     HttpXClient,
     PlaywrightClient,
+    PlaywrightInterceptClient,
     PlaywrightPage,
 )
 from dataservice.config import (
     CacheConfig,
+    DelayConfig,
+    PlaywrightConfig,
+    ProxyConfig,
     RateLimiterConfig,
     RetryConfig,
     ServiceConfig,
@@ -16,19 +19,6 @@ from dataservice.logs import setup_logging
 from dataservice.models import FailedRequest, Request, Response
 from dataservice.service import AsyncDataService, DataService
 
-
-def check_playwright_availability():
-    if not PLAYWRIGHT_AVAILABLE:
-        raise ImportError(
-            "Playwright optional dependency is not installed. Please install it with `pip install python-dataservice[playwright]`."
-        )
-
-
-# Check availability when importing PlaywrightClient or PlaywrightPage
-if "PlaywrightClient" in globals() or "PlaywrightPage" in globals():
-    check_playwright_availability()
-
-
 __all__ = [
     "AsyncDataService",
     "BaseDataItem",
@@ -36,10 +26,14 @@ __all__ = [
     "DataService",
     "DataServiceException",
     "DataWrapper",
+    "DelayConfig",
     "FailedRequest",
     "HttpXClient",
     "PlaywrightClient",
+    "PlaywrightConfig",
+    "PlaywrightInterceptClient",
     "PlaywrightPage",
+    "ProxyConfig",
     "RateLimiterConfig",
     "Request",
     "Response",
